@@ -15,7 +15,7 @@ Dancer2::Plugin::Database - easy database connections for Dancer2 applications
 
 =cut
 
-our $VERSION = '2.08';
+our $VERSION = '2.09';
 
 register_hook qw(database_connected
                  database_connection_lost
@@ -257,7 +257,7 @@ You can also pass a hashref of settings if you wish to provide settings at
 runtime.
 
 
-=head1 CONVENIENCE FEATURES (quick_select, quick_update, quick_insert, quick_delete)
+=head1 CONVENIENCE FEATURES (quick_select, quick_update, quick_insert, quick_delete, quick_count)
 
 The handle returned by the C<database> keyword is a
 L<Dancer::Plugin::Database::Core::Handle> object, which subclasses the C<DBI::db> DBI
@@ -286,6 +286,9 @@ Examples:
   # Fetch all rows from a table (since version 1.30):
   database->quick_select($table_name, {});
 
+  # Retrieve a count of rows matching the criteria:
+  database->quick_count($table_name, {});
+
 There's more extensive documentation on these features in
 L<Dancer::Plugin::Database::Core::Handle>, including using the C<order_by>, C<limit>,
 C<columns> options to sort / limit results and include only specific columns.
